define(["require", "exports", "../utils/formatUndoSnapshot", "roosterjs-editor-dom"], function (require, exports, formatUndoSnapshot_1, roosterjs_editor_dom_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Insert an image to editor at current selection
     * @param editor The editor instance
     * @param imageFileOrSrc Either the image file blob or source string of the image.
     * @param attributes Optional image element attributes
     */
    function insertImage(editor, imageFileOrSrc, attributes) {
        if (typeof imageFileOrSrc == 'string') {
            insertImageWithSrc(editor, imageFileOrSrc, attributes);
        }
        else {
            (0, roosterjs_editor_dom_1.readFile)(imageFileOrSrc, function (dataUrl) {
                if (dataUrl && !editor.isDisposed()) {
                    insertImageWithSrc(editor, dataUrl, attributes);
                }
            });
        }
    }
    exports.default = insertImage;
    function insertImageWithSrc(editor, src, attributes) {
        (0, formatUndoSnapshot_1.default)(editor, function () {
            var image = editor.getDocument().createElement('img');
            image.src = src;
            if (attributes) {
                (0, roosterjs_editor_dom_1.getObjectKeys)(attributes).forEach(function (attribute) {
                    return image.setAttribute(attribute, attributes[attribute]);
                });
            }
            editor.insertNode(image);
        }, 'insertImage');
    }
});
//# sourceMappingURL=insertImage.js.map