define(["require", "exports", "../utils/formatUndoSnapshot"], function (require, exports, formatUndoSnapshot_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Set image alt text for all selected images at selection. If no images is contained
     * in selection, do nothing.
     * The alt attribute provides alternative information for an image if a user for some reason
     * cannot view it (because of slow connection, an error in the src attribute, or if the user
     * uses a screen reader). See https://www.w3schools.com/tags/att_img_alt.asp
     * @param editor The editor instance
     * @param altText The image alt text
     */
    function setImageAltText(editor, altText) {
        editor.focus();
        (0, formatUndoSnapshot_1.default)(editor, function () {
            editor.queryElements('img', 1 /* OnSelection */, function (node) {
                return node.setAttribute('alt', altText);
            });
        }, 'setImageAltText');
    }
    exports.default = setImageAltText;
});
//# sourceMappingURL=setImageAltText.js.map