import applyInlineStyle from '../utils/applyInlineStyle';
import { getFirstLeafNode, getNextLeafSibling } from 'roosterjs-editor-dom';
/**
 * Change the capitalization of text in the selection
 * @param editor The editor instance
 * @param capitalization The case option
 * @param language Optional parameter for language string that should comply to "IETF BCP 47 Tags for
 * Identifying Languages". For example: 'en' or 'en-US' for English, 'tr' for Turkish.
 * Default is the host environment’s current locale.
 */
export default function changeCapitalization(editor, capitalization, language) {
    applyInlineStyle(editor, function (element) {
        for (var node = getFirstLeafNode(element); node; node = getNextLeafSibling(element, node)) {
            if (node.nodeType == 3 /* Text */) {
                try {
                    node.textContent = getCapitalizedText(node.textContent, language);
                }
                catch (_a) {
                    node.textContent = getCapitalizedText(node.textContent, undefined);
                }
            }
        }
    }, 'changeCapitalization');
    function getCapitalizedText(originalText, language) {
        if (originalText === null) {
            return originalText;
        }
        switch (capitalization) {
            case "lowercase" /* Lowercase */:
                return originalText.toLocaleLowerCase(language);
            case "uppercase" /* Uppercase */:
                return originalText.toLocaleUpperCase(language);
            case "capitalize" /* CapitalizeEachWord */:
                var wordArray = originalText.toLocaleLowerCase(language).split(' ');
                for (var i = 0; i < wordArray.length; i++) {
                    wordArray[i] =
                        wordArray[i].charAt(0).toLocaleUpperCase(language) + wordArray[i].slice(1);
                }
                return wordArray.join(' ');
            case "sentence" /* Sentence */:
                // TODO: Add rules on punctuation for internationalization - TASK 104769
                var punctuationMarks = '[\\.\\!\\?]';
                // Find a match of a word character either:
                // - At the beginning of a string with or without preceding whitespace, for
                // example: '  hello world' and 'hello world' strings would both match 'h'.
                // - Or preceded by a punctuation mark and at least one whitespace, for
                // example 'yes. hello world' would match 'y' and 'h'.
                var regex = new RegExp('^\\s*\\w|' + punctuationMarks + '\\s+\\w', 'g');
                return originalText.toLocaleLowerCase(language).replace(regex, function (match) {
                    return match.toLocaleUpperCase(language);
                });
            default:
                return originalText;
        }
    }
}
//# sourceMappingURL=changeCapitalization.js.map