import formatUndoSnapshot from '../utils/formatUndoSnapshot';
import { getObjectKeys, readFile } from 'roosterjs-editor-dom';
/**
 * Insert an image to editor at current selection
 * @param editor The editor instance
 * @param imageFileOrSrc Either the image file blob or source string of the image.
 * @param attributes Optional image element attributes
 */
export default function insertImage(editor, imageFileOrSrc, attributes) {
    if (typeof imageFileOrSrc == 'string') {
        insertImageWithSrc(editor, imageFileOrSrc, attributes);
    }
    else {
        readFile(imageFileOrSrc, function (dataUrl) {
            if (dataUrl && !editor.isDisposed()) {
                insertImageWithSrc(editor, dataUrl, attributes);
            }
        });
    }
}
function insertImageWithSrc(editor, src, attributes) {
    formatUndoSnapshot(editor, function () {
        var image = editor.getDocument().createElement('img');
        image.src = src;
        if (attributes) {
            getObjectKeys(attributes).forEach(function (attribute) {
                return image.setAttribute(attribute, attributes[attribute]);
            });
        }
        editor.insertNode(image);
    }, 'insertImage');
}
//# sourceMappingURL=insertImage.js.map