import { __assign } from "tslib";
import formatUndoSnapshot from '../utils/formatUndoSnapshot';
import { getTableCellMetadata, safeInstanceOf, saveTableCellMetadata, setColor, } from 'roosterjs-editor-dom';
/**
 * Set background color of cells.
 * @param editor The editor instance
 * @param color One of two options:
 **/
export default function applyCellShading(editor, color) {
    editor.focus();
    formatUndoSnapshot(editor, function () {
        var regions = editor.getSelectedRegions();
        regions.forEach(function (region) {
            if (safeInstanceOf(region.rootNode, 'HTMLTableCellElement')) {
                setColor(region.rootNode, color, true /* isBackgroundColor */, editor.isDarkMode(), true /** shouldAdaptFontColor */, editor.getDarkColorHandler());
                var meta = getTableCellMetadata(region.rootNode);
                saveTableCellMetadata(region.rootNode, __assign(__assign({}, meta), { bgColorOverride: true }));
            }
        });
    }, 'applyCellShading');
}
//# sourceMappingURL=applyCellShading.js.map