import formatUndoSnapshot from '../utils/formatUndoSnapshot';
import { VTable } from 'roosterjs-editor-dom';
/**
 * Edit table with given operation. If there is no table at cursor then no op.
 * @param editor The editor instance
 * @param operation Table operation
 */
export default function editTable(editor, operation) {
    var td = editor.getElementAtCursor('TD,TH');
    if (td) {
        formatUndoSnapshot(editor, function () {
            var vtable = new VTable(td);
            saveTableSelection(editor, vtable);
            vtable.edit(operation);
            vtable.writeBack(false /** skipApplyFormat */, editor.getDarkColorHandler());
            editor.transformToDarkColor(vtable.table);
            editor.focus();
            if (isUndefined(vtable.row) || isUndefined(vtable.col)) {
                return;
            }
            var _a = calculateCellToSelect(operation, vtable.row, vtable.col), newCol = _a.newCol, newRow = _a.newRow;
            var newTd = vtable.getCell(newRow, newCol).td;
            if (newTd) {
                editor.select(newTd, 0 /* Begin */);
            }
        }, 'editTable');
    }
}
function isUndefined(n) {
    return n == undefined;
}
function calculateCellToSelect(operation, currentRow, currentCol) {
    var newRow = currentRow;
    var newCol = currentCol;
    switch (operation) {
        case 0 /* InsertAbove */:
            newCol = 0;
            break;
        case 1 /* InsertBelow */:
            newRow += 1;
            newCol = 0;
            break;
        case 2 /* InsertLeft */:
            newRow = 0;
            break;
        case 3 /* InsertRight */:
            newRow = 0;
            newCol += 1;
            break;
    }
    return {
        newRow: newRow,
        newCol: newCol,
    };
}
function saveTableSelection(editor, vtable) {
    var _a;
    var selection = editor.getSelectionRangeEx();
    if (selection && selection.type === 1 /* TableSelection */) {
        vtable.selection = (_a = selection.coordinates) !== null && _a !== void 0 ? _a : null;
    }
}
//# sourceMappingURL=editTable.js.map