import { getTagOfNode } from 'roosterjs-editor-dom';
/**
 * @internal
 * Collapse all selected blocks, return single HTML elements for each block
 * @param editor The editor instance
 * @param forEachCallback A callback function to invoke for each of the collapsed element
 */
export default function collapseSelectedBlocks(editor, forEachCallback) {
    var traverser = editor.getSelectionTraverser();
    if (!traverser) {
        return;
    }
    var block = traverser.currentBlockElement;
    var blocks = [];
    while (block) {
        if (!isEmptyBlockUnderTR(block)) {
            blocks.push(block);
        }
        block = traverser.getNextBlockElement();
    }
    blocks.forEach(function (block) {
        var element = block.collapseToSingleElement();
        forEachCallback(element);
    });
}
function isEmptyBlockUnderTR(block) {
    var startNode = block.getStartNode();
    return (startNode == block.getEndNode() &&
        startNode.nodeType == 3 /* Text */ &&
        ['TR', 'TABLE'].indexOf(getTagOfNode(startNode.parentNode)) >= 0);
}
//# sourceMappingURL=collapseSelectedBlocks.js.map