"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var blockFormat_1 = require("../utils/blockFormat");
var normalizeBlockquote_1 = require("../utils/normalizeBlockquote");
var roosterjs_editor_dom_1 = require("roosterjs-editor-dom");
/**
 * Set indentation at selection
 * If selection contains bullet/numbering list, increase/decrease indentation will
 * increase/decrease the list level by one.
 * @param editor The editor instance
 * @param indentation The indentation option:
 * Indentation.Increase to increase indentation or Indentation.Decrease to decrease indentation
 */
function setIndentation(editor, indentation) {
    var handler = indentation == 0 /* Increase */ ? indent : outdent;
    (0, blockFormat_1.default)(editor, function (region, start, end) {
        var blocks = (0, roosterjs_editor_dom_1.getSelectedBlockElementsInRegion)(region, true /*createBlockIfEmpty*/);
        var blockGroups = [[]];
        for (var i = 0; i < blocks.length; i++) {
            var startNode = blocks[i].getStartNode();
            var vList = (0, roosterjs_editor_dom_1.createVListFromRegion)(region, true /*includeSiblingLists*/, startNode);
            if (vList) {
                while (blocks[i + 1] && vList.contains(blocks[i + 1].getStartNode())) {
                    i++;
                }
                var isTabKeyTextFeaturesEnabled = editor.isFeatureEnabled("TabKeyTextFeatures" /* TabKeyTextFeatures */);
                if (isTabKeyTextFeaturesEnabled &&
                    isFirstItem(vList, startNode) &&
                    shouldHandleWithBlockquotes(indentation, editor, startNode)) {
                    var block = editor.getBlockElementAtNode(vList.rootList);
                    if (block) {
                        blockGroups.push([block]);
                    }
                }
                else {
                    if (start && end) {
                        indentation == 1 /* Decrease */
                            ? vList.setIndentation(start, end, indentation, false /* softOutdent */, isTabKeyTextFeaturesEnabled /* preventItemRemoval */)
                            : vList.setIndentation(start, end, indentation);
                        vList.writeBack(editor.isFeatureEnabled("ReuseAllAncestorListElements" /* ReuseAllAncestorListElements */), editor.isFeatureEnabled("DisableListChain" /* DisableListChain */));
                        blockGroups.push([]);
                    }
                }
            }
            else {
                blockGroups[blockGroups.length - 1].push(blocks[i]);
            }
        }
        blockGroups.forEach(function (group) { return handler(region, group); });
    }, function () {
        var selection = editor.getSelectionRangeEx();
        if (selection.type == 1 /* TableSelection */ &&
            selection.coordinates &&
            (0, roosterjs_editor_dom_1.isWholeTableSelected)(new roosterjs_editor_dom_1.VTable(selection.table), selection.coordinates)) {
            if (indentation == 1 /* Decrease */) {
                var quote = editor.getElementAtCursor('blockquote', selection.table);
                if (quote) {
                    (0, roosterjs_editor_dom_1.unwrap)(quote);
                }
            }
            else if (indentation == 0 /* Increase */) {
                (0, roosterjs_editor_dom_1.wrap)(selection.table, 2 /* BlockquoteWrapper */);
            }
            return false;
        }
        return true;
    }, 'setIndentation');
    function indent(region, blocks) {
        var nodes = (0, roosterjs_editor_dom_1.collapseNodesInRegion)(region, blocks);
        (0, roosterjs_editor_dom_1.wrap)(nodes, 2 /* BlockquoteWrapper */);
        var quotesHandled = [];
        nodes.forEach(function (node) { return (0, normalizeBlockquote_1.default)(node, quotesHandled); });
    }
}
exports.default = setIndentation;
function outdent(region, blocks) {
    blocks.forEach(function (blockElement) {
        var node = blockElement.collapseToSingleElement();
        var quote = (0, roosterjs_editor_dom_1.findClosestElementAncestor)(node, region.rootNode, 'blockquote');
        if (quote) {
            if (node == quote) {
                node = (0, roosterjs_editor_dom_1.wrap)((0, roosterjs_editor_dom_1.toArray)(node.childNodes));
            }
            while (node && (0, roosterjs_editor_dom_1.isNodeInRegion)(region, node) && (0, roosterjs_editor_dom_1.getTagOfNode)(node) != 'BLOCKQUOTE') {
                node = (0, roosterjs_editor_dom_1.splitBalancedNodeRange)(node);
            }
            if (node && (0, roosterjs_editor_dom_1.isNodeInRegion)(region, node)) {
                (0, roosterjs_editor_dom_1.unwrap)(node);
            }
        }
    });
}
function isFirstItem(vList, startNode) {
    var _a;
    return (((_a = vList.items[0]) === null || _a === void 0 ? void 0 : _a.getNode()) == startNode &&
        vList.getListItemIndex(startNode) == (vList.getStart() || 1));
}
function shouldHandleWithBlockquotes(indentation, editor, startNode) {
    return (indentation == 0 /* Increase */ || editor.getElementAtCursor('blockquote', startNode));
}
//# sourceMappingURL=setIndentation.js.map