"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var formatUndoSnapshot_1 = require("../utils/formatUndoSnapshot");
var setBackgroundColor_1 = require("../format/setBackgroundColor");
var roosterjs_editor_dom_1 = require("roosterjs-editor-dom");
/**
 * Insert table into editor at current selection
 * @param editor The editor instance
 * @param columns Number of columns in table, it also controls the default table cell width:
 * if columns &lt;= 4, width = 120px; if columns &lt;= 6, width = 100px; else width = 70px
 * @param rows Number of rows in table
 * @param format (Optional) The table format. If not passed, the default format will be applied:
 * background color: #FFF; border color: #ABABAB
 */
function insertTable(editor, columns, rows, format) {
    var document = editor.getDocument();
    var table = document.createElement('table');
    table.cellSpacing = '0';
    table.cellPadding = '1';
    for (var i = 0; i < rows; i++) {
        var tr = document.createElement('tr');
        table.appendChild(tr);
        for (var j = 0; j < columns; j++) {
            var td = document.createElement('td');
            tr.appendChild(td);
            td.appendChild(document.createElement('br'));
            td.style.width = getTableCellWidth(columns);
        }
    }
    editor.focus();
    (0, formatUndoSnapshot_1.default)(editor, function () {
        var element = editor.getElementAtCursor();
        if (element === null || element === void 0 ? void 0 : element.style.backgroundColor) {
            (0, setBackgroundColor_1.default)(editor, 'transparent');
        }
        var vtable = new roosterjs_editor_dom_1.VTable(table);
        // Assign default vertical align
        format = format || { verticalAlign: 'top' };
        vtable.applyFormat(format || {});
        vtable.writeBack();
        editor.insertNode(table);
        editor.runAsync(function (editor) {
            return editor.select(new roosterjs_editor_dom_1.Position(table, 0 /* Begin */).normalize());
        });
    }, 'insertTable');
}
exports.default = insertTable;
function getTableCellWidth(columns) {
    if (columns <= 4) {
        return '120px';
    }
    else if (columns <= 6) {
        return '100px';
    }
    else {
        return '70px';
    }
}
//# sourceMappingURL=insertTable.js.map