"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var roosterjs_editor_dom_1 = require("roosterjs-editor-dom");
/**
 * @internal
 * Collapse all selected blocks, return single HTML elements for each block
 * @param editor The editor instance
 * @param forEachCallback A callback function to invoke for each of the collapsed element
 */
function collapseSelectedBlocks(editor, forEachCallback) {
    var traverser = editor.getSelectionTraverser();
    if (!traverser) {
        return;
    }
    var block = traverser.currentBlockElement;
    var blocks = [];
    while (block) {
        if (!isEmptyBlockUnderTR(block)) {
            blocks.push(block);
        }
        block = traverser.getNextBlockElement();
    }
    blocks.forEach(function (block) {
        var element = block.collapseToSingleElement();
        forEachCallback(element);
    });
}
exports.default = collapseSelectedBlocks;
function isEmptyBlockUnderTR(block) {
    var startNode = block.getStartNode();
    return (startNode == block.getEndNode() &&
        startNode.nodeType == 3 /* Text */ &&
        ['TR', 'TABLE'].indexOf((0, roosterjs_editor_dom_1.getTagOfNode)(startNode.parentNode)) >= 0);
}
//# sourceMappingURL=collapseSelectedBlocks.js.map