"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.experimentCommitListChains = void 0;
var roosterjs_editor_dom_1 = require("roosterjs-editor-dom");
/**
 * Commit changes of all list changes when experiment features are allowed
 * @param editor The Editor object
 * @param chains List chains to commit
 */
function commitListChains(editor, chains) {
    if ((chains === null || chains === void 0 ? void 0 : chains.length) > 0) {
        var range = editor.getSelectionRange();
        var start = range && roosterjs_editor_dom_1.Position.getStart(range);
        var end = range && roosterjs_editor_dom_1.Position.getEnd(range);
        var shouldReuseAllAncestorListElements_1 = editor.isFeatureEnabled("ReuseAllAncestorListElements" /* ReuseAllAncestorListElements */);
        var shouldDisableListChain_1 = editor.isFeatureEnabled("DisableListChain" /* DisableListChain */);
        chains.forEach(function (chain) {
            return chain.commit(shouldReuseAllAncestorListElements_1, shouldDisableListChain_1);
        });
        if (start && end) {
            editor.select(start, end);
        }
    }
}
exports.default = commitListChains;
/**
 * @deprecated
 * Same with commitListChains, keep this export just for backward compatibility
 */
exports.experimentCommitListChains = commitListChains;
//# sourceMappingURL=commitListChains.js.map