"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var formatUndoSnapshot_1 = require("./formatUndoSnapshot");
var roosterjs_editor_dom_1 = require("roosterjs-editor-dom");
/**
 * @internal
 * Execute a document command
 * @param editor The editor instance
 * @param command The command to execute
 * @param addUndoSnapshotWhenCollapsed Optional, set to true to always add undo snapshot even current selection is collapsed.
 * Default value is false.
 * @param doWorkaroundForList Optional, set to true to do workaround for list in order to keep current format.
 * Default value is false.
 */
function execCommand(editor, command, apiName) {
    editor.focus();
    var formatter = function () { return editor.getDocument().execCommand(command, false, undefined); };
    var selection = editor.getSelectionRangeEx();
    if (selection && selection.areAllCollapsed) {
        editor.addUndoSnapshot();
        var formatState = editor.getPendableFormatState(false /* forceGetStateFromDom */);
        formatter();
        var formatName = (0, roosterjs_editor_dom_1.getObjectKeys)(roosterjs_editor_dom_1.PendableFormatCommandMap).filter(function (x) { return roosterjs_editor_dom_1.PendableFormatCommandMap[x] == command; })[0];
        if (formatName) {
            formatState[formatName] = !formatState[formatName];
            editor.triggerPluginEvent(13 /* PendingFormatStateChanged */, {
                formatState: formatState,
            });
        }
    }
    else {
        (0, formatUndoSnapshot_1.default)(editor, function () {
            var needToSwitchSelection = selection.type != 0 /* Normal */;
            selection.ranges.forEach(function (range) {
                if (needToSwitchSelection) {
                    editor.select(range);
                }
                formatter();
            });
            if (needToSwitchSelection) {
                editor.select(selection);
            }
        }, apiName);
    }
}
exports.default = execCommand;
//# sourceMappingURL=execCommand.js.map